Skip to contents

An abstract class for a DICOM Resource

Value

An R6 instance of class "Resource".

Active bindings

identifier

Orthanc identifier of the resource.

main_dicom_tags

Main DICOM tags for the resource.

is_locked

Get or set whether resource is locked.

Methods


Method new()

Create a new Resource.

Usage

Resource$new(id, client, lock_children = FALSE)

Arguments

id

Orthanc identifier of the resource.

client

Orthanc client.

lock_children

If lock_children is TRUE, the resource children (e.g., instances of a series via Series$instances) will be cached at the first query rather than queried every time. This is useful when you want to filter the children of a resource and want to maintain the filter result.


Method get_main_information()

Get main information for the resource.

Usage

Resource$get_main_information()


Method print()

Print a Resource object.

Usage

Resource$print(...)

Arguments

...

Not currently used.


Method set_child_resources()

Set child resources.

Usage

Resource$set_child_resources(resources)

Arguments

resources

List of resources.


Method clone()

The objects of this class are cloneable with this method.

Usage

Resource$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.