An abstract class for a DICOM Instance resource.
Super class
orthanc::Resource -> Instance
Active bindings
uidSOPInstanceUID
file_sizeFile size
creation_dateCreation Date
series_identifierParent series identifier
parent_seriesParent series
parent_studyParent study
parent_patientParent patient
acquisition_numberAcquisition Number
image_indexImage Index
image_orientation_patientImage Orientation Patient
image_position_patientImage Position Patient
image_commentsImage Comments
instance_numberInstance Number
temporal_position_identifierTemporal Position Identifier
tagsTags
simplified_tagsSimplified Tags
labelsGet or add labels
statisticsStatistics
list_framesList frames (zero-based indexing)
framesNumber of frames
rowsNumber of rows
columnsNumber of columns
shapeShape (rows x columns x frames (if multi-frame))
dimNumber of dimensions
slice_thicknessSlice thickness
pixel_spacingPixel spacing
Methods
Method get_dicom_file_content()
Retrieves bytes of DICOM file content
This method retrieves bytes corresponding to the DICOM file.
Method anonymize()
Anonymize Instance
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method modify()
Modify an Instance
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
Method download_image()
Download instance as an image.
Usage
Instance$download_image(
path,
frame = 0L,
format = c("png", "jpeg"),
render = TRUE,
params = NULL,
...
)Arguments
pathPath on disk.
frameIndex of the frame (starts at
0L). Default is0L.formatOne of
"png"or"jpeg". Default is"png".renderShould the image be scaled (with
RescaleSlopeandRescaleIntercept) and windowed (withWindowCenterandWindowWidth, if available). Default isTRUE.paramsOptional named-list of query parameters.
...Optional arguments passed on to
png::writePNG()orjpeg::writeJPEG().