An abstract class for a DICOM Patient resource.
Super class
orthanc::Resource -> Patient
Active bindings
patient_idPatient ID
namePatient Name
birth_datePatient Birth Date
sexPatient Sex
other_patient_idsOther Patient IDs
is_stableIs stable?
last_updateLast Update
labelsGet or add labels
protectedGet or set if patient is protected against recycling
studiesStudies
studies_idsStudies identifiers
seriesSeries
series_idsSeries identifiers
instancesInstances
instances_idsInstances identifiers
instances_tagsInstances tags
num_studiesNumber of studies
num_seriesNumber of series
num_instancesNumber of instances
shared_tagsShared tags
statisticsStatistics
Methods
Method anonymize()
Anonymize Patient
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method anonymize_as_job()
Anonymize Patient
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method modify()
Modify Patient
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
Method modify_as_job()
Modify Patient
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.