An abstract class for a DICOM Resource
Active bindings
identifierOrthanc identifier of the resource.
main_dicom_tagsMain DICOM tags for the resource.
is_lockedGet or set whether resource is locked.
Methods
Method new()
Create a new Resource.
Usage
Resource$new(id, client, lock_children = FALSE)Arguments
idOrthanc identifier of the resource.
clientOrthancclient.lock_childrenIf
lock_childrenisTRUE, the resource children (e.g., instances of a series viaSeries$instances) will be cached at the first query rather than queried every time. This is useful when you want to filter the children of a resource and want to maintain the filter result.