An abstract class for a DICOM Series resource.
Super class
orthanc::Resource -> Series
Active bindings
instancesInstances
instances_idsInstances identifiers
num_instancesNumber of instances
instances_tagsInstances tags
uidSeriesInstanceUID
manufacturerManufacturer
dateSeries Date
modalityModality
series_numberSeries Number
performed_procedure_step_descriptionPerformed Procedure Step Description
protocol_nameProtocol Name
station_nameStation Name
descriptionSeries Description
body_part_examinedBody Part Examined
sequence_nameSequence Name
cardiac_number_of_imagesCardiac Number of Images
image_in_acquisitionImages in Acquisition
number_of_temporal_positionsNumber of Temporal Positions
number_of_slicesNumber of Slices
number_of_time_slicesNumber of Time Slices
image_orientation_patientImage Orientation Patient
series_typeSeries Type
operators_nameOperators Name
acquisition_device_processing_descriptionAcquisition Device Processing Description
contrast_bolus_agentContrast Bolus Agent
is_stableIs stable?
last_updateLast Update
labelsGet or add labels
study_identifierParent study identifier
parent_studyParent study
parent_patientParent patient
shared_tagsShared tags
statisticsStatistics
Methods
Method anonymize()
Anonymize Series
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method anonymize_as_job()
Anonymize Series
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method modify()
Modify Series
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
Method modify_as_job()
Modify Series
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.