Skip to contents

An abstract class for a DICOM Study resource.

Value

An R6 instance of class "Study".

Super class

orthanc::Resource -> Study

Active bindings

patient_identifier

Parent patient identifier

parent_patient

Parent patient

referring_physician_name

Referring Physician Name

requesting_physician

Requesting Physician

date

Study Date

study_id

Study ID

uid

StudyInstanceUID

patient_information

Patient Main DICOM Tags

series

Series

series_ids

Series identifiers

instances

Instances

instances_ids

Instances identifiers

num_series

Number of series

num_instances

Number of instances

instances_tags

Instances tags

accession_number

Accession Number

description

Description

institution_name

Institution Name

requested_procedure_description

Requested Procedure Description.

is_stable

Is stable?

last_update

Last Update

labels

Get or add labels

shared_tags

Shared Tags

statistics

Statistics

Methods

Inherited methods


Method get_main_information()

Get study information.

Usage

Study$get_main_information()


Method add_label()

Add label to resource.

Usage

Study$add_label(label)

Arguments

label

Label.


Method has_label()

Test if resource has label.

Usage

Study$has_label(label)

Arguments

label

Label.


Method remove_label()

Delete label from resource.

Usage

Study$remove_label(label)

Arguments

label

Label.


Method anonymize()

Anonymize Study

Usage

Study$anonymize(
  remove = list(),
  replace = list(),
  keep = list(),
  keep_private_tags = FALSE,
  keep_source = TRUE,
  priority = 0L,
  permissive = FALSE,
  private_creator = NULL,
  force = FALSE,
  dicom_version = NULL
)

Arguments

remove

List of tags to remove.

replace

Named-list of tags to replce.

keep

List of tags to keep unchanged.

keep_private_tags

Keep private tags from DICOM instance.

keep_source

Keep original resource.

priority

Priority of the job.

permissive

Ignore errors during individual steps of the job?

private_creator

Private creator to be used for private tags in replace.

force

Force tags to be changed.

dicom_version

Version of the DICOM standard to use for anonymization.


Method anonymize_as_job()

Anonymize Study

Usage

Study$anonymize_as_job(
  remove = list(),
  replace = list(),
  keep = list(),
  keep_private_tags = FALSE,
  keep_source = TRUE,
  priority = 0L,
  permissive = FALSE,
  private_creator = NULL,
  force = FALSE,
  dicom_version = NULL
)

Arguments

remove

List of tags to remove.

replace

Named-list of tags to replce.

keep

List of tags to keep unchanged.

keep_private_tags

Keep private tags from DICOM instance.

keep_source

Keep original resource.

priority

Priority of the job.

permissive

Ignore errors during individual steps of the job?

private_creator

Private creator to be used for private tags in replace.

force

Force tags to be changed.

dicom_version

Version of the DICOM standard to use for anonymization.


Method modify()

Modify Study

Usage

Study$modify(
  remove = list(),
  replace = list(),
  keep = list(),
  remove_private_tags = FALSE,
  keep_source = TRUE,
  priority = 0L,
  permissive = FALSE,
  private_creator = NULL,
  force = FALSE
)

Arguments

remove

List of tags to remove.

replace

Named-list of tags to replce.

keep

List of tags to keep unchanged.

remove_private_tags

Remove private tags from DICOM instance.

keep_source

Keep original resource.

priority

Priority of the job.

permissive

Ignore errors during individual steps of the job?

private_creator

Private creator to be used for private tags in replace.

force

Force tags to be changed.


Method modify_as_job()

Modify Study as Job

Usage

Study$modify_as_job(
  remove = list(),
  replace = list(),
  keep = list(),
  remove_private_tags = FALSE,
  keep_source = TRUE,
  priority = 0L,
  permissive = FALSE,
  private_creator = NULL,
  force = FALSE
)

Arguments

remove

List of tags to remove.

replace

Named-list of tags to replce.

keep

List of tags to keep unchanged.

remove_private_tags

Remove private tags from DICOM instance.

keep_source

Keep original resource.

priority

Priority of the job.

permissive

Ignore errors during individual steps of the job?

private_creator

Private creator to be used for private tags in replace.

force

Force tags to be changed.


Method get_zip_archive_content()

Get bytes of the zip archive.

Usage

Study$get_zip_archive_content()


Method download_archive()

Download zip archive to path.

Usage

Study$download_archive(path, stream = FALSE)

Arguments

path

Path on disk.

stream

Should the resource be streamed and written to disk in chunks? Default is FALSE, which means the resource file contents are retrieved in their entirety and written to disk all at once.


Method get_shared_tags()

Retrieve the shared tags of the study.

Usage

Study$get_shared_tags()


Method remove_empty_series()

Remove empty series from study.

Usage

Study$remove_empty_series()


Method clone()

The objects of this class are cloneable with this method.

Usage

Study$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.