An abstract class for a DICOM Study resource.
Super class
orthanc::Resource -> Study
Active bindings
patient_identifierParent patient identifier
parent_patientParent patient
referring_physician_nameReferring Physician Name
requesting_physicianRequesting Physician
dateStudy Date
study_idStudy ID
uidStudyInstanceUID
patient_informationPatient Main DICOM Tags
seriesSeries
series_idsSeries identifiers
instancesInstances
instances_idsInstances identifiers
num_seriesNumber of series
num_instancesNumber of instances
instances_tagsInstances tags
accession_numberAccession Number
descriptionDescription
institution_nameInstitution Name
requested_procedure_descriptionRequested Procedure Description.
is_stableIs stable?
last_updateLast Update
labelsGet or add labels
shared_tagsShared Tags
statisticsStatistics
Methods
Method anonymize()
Anonymize Study
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method anonymize_as_job()
Anonymize Study
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
keep_private_tagsKeep private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
dicom_versionVersion of the DICOM standard to use for anonymization.
Method modify()
Modify Study
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.
Method modify_as_job()
Modify Study as Job
Arguments
removeList of tags to remove.
replaceNamed-list of tags to replce.
keepList of tags to keep unchanged.
remove_private_tagsRemove private tags from DICOM instance.
keep_sourceKeep original resource.
priorityPriority of the job.
permissiveIgnore errors during individual steps of the job?
private_creatorPrivate creator to be used for private tags in replace.
forceForce tags to be changed.